<div align=center>

<img width="250" height="312" src="https://github.com/zhenxun-org/zhenxun-utils/blob/main/docs_image/tt.jpg"/>

</div>

<div align="center">

# zhenxun-utils

_✨ 小真寻的工具类依赖 ✨_

![python](https://img.shields.io/badge/python-v3.9%2B-blue)
![nonebot](https://img.shields.io/badge/nonebot-v2.1.3-yellow)
![onebot](https://img.shields.io/badge/onebot-v11-black)
[![license](https://img.shields.io/badge/license-AGPL3.0-FE7D37)](https://github.com/HibiKier/zhenxun_bot/blob/main/LICENSE)

</div>

## 📖 介绍

[小真寻](https://github.com/HibiKier/zhenxun_bot)的工具类依赖仓库！

> [!NOTE]
>
> <div align="center"><b>小真寻也很可爱呀，也会很喜欢你！</b></div>
>
> <div align="center"><img width="235" height="235" src="https://github.com/zhenxun-org/zhenxun-utils/blob/main/docs_image/tt3.png"/><img width="235" height="235" src="https://github.com/zhenxun-org/zhenxun-utils/blob/main/docs_image/tt1.png"/><img width="235" height="235" src="https://github.com/zhenxun-org/zhenxun-utils/blob/main/docs_image/tt2.png"/></div>

## 💿 安装

```python
pip install zhenxun-utils
```

## ❤ 感谢

- 可爱的小真寻 Bot [`zhenxun_bot`](https://github.com/HibiKier/zhenxun_bot): 我谢我自己，桀桀桀
